#
# spec file for package cura-engine-lulzbot
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cura-engine-lulzbot
Version:        3.6.21
Release:        bp154.1.16
Summary:        3D printer control software
License:        AGPL-3.0-only
Group:          Hardware/Printing
Conflicts:      cura-engine
URL:            https://code.alephobjects.com/diffusion/CTE/cura-engine.git
Source0:        CuraEngine-%{version}.tar.xz
Source1:        CuraEngine.1
# X-OPENSUSE-PATCH fix-build.patch for new libArcus
Patch1:         fix-build.patch
# PATCH-FIX-OPENSUSE CuraEngine-gcc9.patch loose based on a patch from fedora
Patch2:         CuraEngine-gcc9.patch
%if 0%{?suse_version} < 1500
BuildRequires:  gcc6-c++
#!BuildIgnore:  libgcc_s1
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  cmake
BuildRequires:  cppunit-devel
BuildRequires:  libArcus-devel
BuildRequires:  stb-devel
# No 32bit support anymore. aarch64 support was added later (please use regular cura-engine for aarch64)
ExcludeArch:    %ix86 %arm aarch64

%description
CuraEngine is an engine for processing 3D models
into 3D printing instruction for Ultimaker and other GCode based 3D printers.
It is part of the larger open source project called "Cura".

This is the LulzBot variation of the engine.

%prep
%setup -q -n CuraEngine-%version
%patch1 -p1
%if 0%{?suse_version} > 1500
%patch2 -p0
%endif

%build
%if 0%{?suse_version} < 1500
export CC=gcc-6
export CXX=g++-6
%endif
%cmake -DCMAKE_POSITION_INDEPENDENT_CODE="true" \
       -DBUILD_SHARED_LIBS="false" \
       -DCMAKE_BUILD_TYPE=Release \
       -DBUILD_TESTS=ON
%make_jobs

%install
cd build
%make_install

mv %buildroot%_bindir/CuraEngine{,-lulzbot}
install -Dm0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/CuraEngine-lulzbot.1

%check
cd build
make test

%files
%license LICENSE
%doc Changelog.md README.md docs
%_bindir/CuraEngine-lulzbot
%_mandir/man1/CuraEngine-lulzbot.1*

%changelog
* Mon Aug 30 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- aarch64 is not supported in this old version. Please use regular
  cura-engine instead.
* Fri Oct 11 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.21
  * no code changes
* Mon Oct  7 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.20
  * no code changes
* Thu Sep  5 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.19
  * no code changes
* Mon Aug 12 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.18
  * no code changes
- disabled failing 32bit builds, not anymore supported
* Mon Jul  8 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.13
  * no code changes
* Tue Jun 25 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.10
  * no code changes
* Fri Jun 14 2019 Adrian Schröter <adrian@suse.de>
- fix build with current libArcus
- fix build with gcc9 (CuraEngine-gcc9.patch)
* Mon May 27 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.9
  T7039: Fixed material first layer flow setting
* Mon May  6 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.8
  * no code changes
* Wed May  1 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.7
  * no code changes
* Thu Apr 18 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.6
    T6357: Changed extruder switch mechanics
    T5146: fixed extruder slowing if time < min_layer_time
* Fri Apr  5 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.5
  * merged 32bit fixes, obsoletes fix-32bit-build.patch
* Thu Feb 21 2019 Adrian Schröter <adrian@suse.de>
- fix 32bit build
  * adding fix-32bit-build.patch
* Wed Feb 20 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.4
  * no code changes
* Mon Jan  7 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.1
  https://code.alephobjects.com/w/cura-lulzbot/
- run test suite during build
- Add fix-build.patch to use upstream libArcus lib
* Tue Nov 20 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.2.32
  * version update only
* Mon Oct 22 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.2.29
  * version update only
* Tue Sep 25 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.2.28
  * version update only
  * obsoletes fix-build.patch
* Mon Aug  6 2018 adrian@suse.de
- update to version 3.2.24
  * version update only
* Wed Jul 25 2018 adrian@suse.de
- use upstream libArcus instead of lulzbot flavor
* Fri Jul 13 2018 adrian@suse.de
- update to version 3.2.23
  * version update only
* Tue Jul  3 2018 adrian@suse.de
- update to version 3.2.22
  * added backlash_fading option
* Wed May 30 2018 adrian@suse.de
- update to version 3.2.21
  * version update only
* Mon May 14 2018 adrian@suse.de
- update to version 3.2.20
  * version update only
* Wed May  2 2018 adrian@suse.de
- update to version 3.2.19
  * version update only
* Thu Apr 19 2018 adrian@suse.de
- update to version 3.2.18
  * version only
* Fri Apr 13 2018 stefan.bruens@rwth-aachen.de
- Link private lib_CuraEngine statically to binary
- Use CMAKE_POSITION_INDEPENDENT_CODE instead of mangling CFLAGS
* Tue Apr  3 2018 adrian@suse.de
- update to version 3.2.16
  * Layer hight and count fixes
* Thu Mar  8 2018 adrian@suse.de
- update to version 3.2.9
  * version update only
* Mon Mar  5 2018 adrian@suse.de
- update to version 3.2.7
  * version update only
* Mon Feb 12 2018 adrian@suse.de
- update to version 3.2.3
* Wed Jan 31 2018 jengelh@inai.de
- Trim rhetorics from description.
* Wed Jan 31 2018 adrian@suse.de
- update to version 3.2.1
* Fri Nov  3 2017 adrian@suse.de
- forked and update to lulzbot version 2.6.43
